import turtle

class Rectangle():
  def __init__(self, length, width, pencolor, fillcolor):
    self.length = length
    self.width = width
    self.pencolor = pencolor
    self.fillcolor = fillcolor

  def draw(self, x, y):
    t = turtle.Pen()
    t.penup()
    t.forward(x)
    t.left(90)
    t.forward(y)
    t.pendown()
    t.pencolor(self.pencolor)
    t.fillcolor(self.fillcolor)
    t.begin_fill()
    t.forward(self.length)
    t.left(90)
    t.forward(self.width)
    t.left(90)
    t.forward(self.length)
    t.left(90)
    t.forward(self.width)
    t.left(90)
    t.end_fill()
    t.hideturtle()

if __name__ == "__main__":
  rect = Rectangle(90,90,(1,1,0), (0,0,0.5))
  rect.draw(20,20)
  turtle.mainloop()



import turtle

class Circle():
  def __init__(self, pencolor, fillcolor):
    self.pencolor = pencolor
    self.fillcolor = fillcolor

  def draw(self, x, y, radius):
    t = turtle.Pen()
    t.penup()
    t.forward(x)
    t.left(90)
    t.forward(y)
    t.pendown()
    t.pencolor(self.pencolor)
    t.fillcolor(self.fillcolor)
    t.begin_fill()
    t.circle(radius)
    t.end_fill()
    t.hideturtle()


if __name__ == "__main__":
    circle = Circle((1,0,0), (0,0,1))
    circle.draw(0,0,50)
    turtle.mainloop()



import pathlib
from setuptools import setup

# The directory containing this file
HERE = pathlib.Path(__file__).parent

# The text of the README file
README = (HERE / "README.md").read_text()

# This call to setup() does all the work
setup(
    name="turtledrawing",
    version="5.0.0",
    description="Draw Shapes with the Turtle Module.",
    long_description=README,
    long_description_content_type="text/markdown",
    author="orcawhale38",
    author_email="orcawhale2008@gmail.com",
    license="MIT",
    classifiers=[
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
    ],
    packages=["shapes"],
    include_package_data=True,
    url="https://github.com/NotOrca22/learning-turtle",
    entry_points={
        "console_scripts": [
            "realpython=reader.__main__:main",
        ]
    },
)


from shapes import circle, rectangle
import turtle
class Car:
    def __init__(self,hoodLength, hoodWidth, bodyLength, bodyWidth, bodyPenColor, bodyFillColor, hoodPenColor, hoodFillColor, wheelPenColor, wheelFillColor,wheelRadius):
        self.body = rectangle.Rectangle(bodyLength, bodyWidth, bodyPenColor, bodyFillColor)
        self.hood = rectangle.Rectangle(hoodLength, hoodWidth, hoodPenColor, hoodFillColor)
        self.wheel1 = circle.Circle(wheelPenColor, wheelFillColor)
        self.wheel2 = circle.Circle(wheelPenColor, wheelFillColor)
        self.wheelRadius = wheelRadius

    def draw(self, x, y):
        self.body.draw(x, y)
        # t.penup()
        # t.left(90)
        # t.forward(self.body.length)
        # t.left(90)
        # t.forward(self.body.width/2)
        # t.pendown()
        self.hood.draw(x-(self.body.width/2)+(self.hood.width/2), y+self.body.length)
        self.wheel1.draw(x,y-self.wheelRadius,self.wheelRadius)
        self.wheel2.draw(x-(self.body.width-2*self.wheelRadius), y-self.wheelRadius, self.wheelRadius)

if __name__ == "__main__":
    car = Car(20,50,30,100,(1,0,0),(1,0,0), (0,1,0), (0,0,1),(0,0,0), (0,0,0),10)
    car.draw(40,40)
    car.draw(-80, -10)
    turtle.mainloop()